;; Generated package description from tuareg.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "tuareg" "3.0.20.20260615.32" "OCaml mode" '((emacs "26.3") (caml "4.8")) :commit "95b4eb6c28d97c9cf4e966a1987ebae1f225edeb" :authors '(("Albert Cohen" . "Albert.Cohen@inria.fr") ("Sam Steingold" . "sds@gnu.org") ("Christophe Troestler" . "Christophe.Troestler@umons.ac.be") ("Till Varoquaux" . "till@pps.jussieu.fr") ("Sean McLaughlin" . "seanmcl@gmail.com") ("Stefan Monnier" . "monnier@iro.umontreal.ca")) :maintainer '(("Christophe Troestler" . "Christophe.Troestler@umons.ac.be") ("Stefan Monnier" . "monnier@iro.umontreal.ca")) :keywords '("ocaml" "languages") :url "https://github.com/ocaml/tuareg")
